function [sumWeightedSimilarityPvalue sumWeightedSimilarity] = calculate_measure_convergence_significance(similarity, dipoleLocation, headGrid, standardDeviationOfEstimatedDipoleLocation, numberOfPermutations)

if nargin<4
    standardDeviationOfEstimatedDipoleLocation = 12; % mm
end;

if nargin < 5
    numberOfPermutations = 200;
end;

sumWeightedSimilarity = headGrid.xCube * 0;

standardDeviationOfEstimatedErrorInDipoleLocationPowerTwo = standardDeviationOfEstimatedDipoleLocation ^ 2;

similarity = similarity - diag(diag(similarity)); % remove ones on the diagonal


surrogateSumWeightedSimilarity = zeros(1, numberOfPermutations);
sumWeightedSimilarityPvalue = ones(size(headGrid.xCube));

clear randomPermutation;
for permutationNumber = 1:numberOfPermutations
    % randomPermutation(permutationNumber,:) = randperm(size(similarity,1)); % without repetition
    randomPermutation(permutationNumber,:) = randi(size(similarity,1), 1, size(similarity,1)); % with repetition
end;

pr.progress('init'); % start the text based progress bar

for i=1:numel(headGrid.xCube)
    if headGrid.insideBrainCube(i)
        
        if mod(i,10) ==0
            %fprintf('Percent done = %d\n', round(100 * i / numel(headGrid.xCube)));
             pr.progress(i / numel(headGrid.xCube), sprintf('\npercent done %d/100',round(100*i / numel(headGrid.xCube))));
        end;
        
        pos = [headGrid.xCube(i) headGrid.yCube(i) headGrid.zCube(i)];
        distanceToDipoles = sum((dipoleLocation - repmat(pos, size(dipoleLocation,1), 1))' .^2) .^ 0.5;
        
        % pass distance to dipoles through a gaussian kernel with specified standard deviation.
        gaussianPassedDistanceToDipoles = sqrt(1/(2 * pi * standardDeviationOfEstimatedErrorInDipoleLocationPowerTwo)) * exp(-distanceToDipoles.^2 / (2 * standardDeviationOfEstimatedErrorInDipoleLocationPowerTwo));
        
        gaussianWeightMatrix = repmat(gaussianPassedDistanceToDipoles,length(gaussianPassedDistanceToDipoles),1);
        
        normalizationMatrix = gaussianWeightMatrix .* gaussianWeightMatrix';
        normalizationMatrix = normalizationMatrix / sum(normalizationMatrix(:));
        
        similarityWeightedByGauissian = similarity .* normalizationMatrix;
        sumWeightedSimilarity(i) = sum(similarityWeightedByGauissian(:));
        
        % bootstapping with permutation
        for permutationNumber = 1:numberOfPermutations
            surrogateSimilarityWeightedByGauissian = similarity(randomPermutation(permutationNumber,:), randomPermutation(permutationNumber,:)) .* normalizationMatrix;
            surrogateSumWeightedSimilarity(permutationNumber) = sum(surrogateSimilarityWeightedByGauissian(:));
        end;
        
        sumWeightedSimilarityPvalue(i) = sum(surrogateSumWeightedSimilarity > sumWeightedSimilarity(i)) / numberOfPermutations;
        
    end;
end;

pause(.1);
pr.progress('close'); % duo to some bug need a pause() before
fprintf('\n');

% we can only be sure that the significance is less than 1/numberOfPermutations
sumWeightedSimilarityPvalue = max(sumWeightedSimilarityPvalue, (1 / numberOfPermutations) - eps);