classdef dipoleAndMeasureOfStudyItc < pr.dipoleAndMeasureOfStudy
    % holds ITCs from one or several conditions in a linearized way.
    % the first dimension is the linearized version of the ITC for concatenated subset of
    % consitions.
    % the second dimension of value is dipoles.
    properties
        time  = []; % an array that hold the times (in ms) associated with ITC.
        frequency = [];
    end % properties
    properties (Constant = true)
        numberOfMeasureDimensions = 2; % number of dimensions in measure
    end;% properties
    methods (Access = 'protected')
        function plotMeasureAsArrayInCell(obj, measureAsArrayInCell, title, varargin)
            std_plottf(obj.time, obj.frequency, measureAsArrayInCell,   'titles', title, 'datatype','itc',varargin{:});
        end;
    end;
    methods
        function obj = dipoleAndMeasureOfStudyItc(STUDY, ALLEEG, varargin) % constructor
            % conditionId is an optional input that specifies which conditions should be included.
            % by default all conditions are included.
            
            superClassArgs = {};
            
            if nargin>1
                superClassArgs{1} = STUDY;
                superClassArgs{2} = ALLEEG;
            end;
            
            if nargin>2
                for i=1:length(varargin) % pass additional parameters in varargin to parent dipoleAndMeasureOfStudy class
                    superClassArgs{2+i} = varargin{i};
                end;
            end;
            
            obj = obj@pr.dipoleAndMeasureOfStudy(superClassArgs{:}); % call the super class constructor
            
            if nargin > 0
                
                [STUDY, itcdataConditionByGroup] = std_readitc(STUDY, ALLEEG,  'clusters', 1);
                
                % combine conditions in each group, then combine groups together
                for group=1:obj.numberOfGroups
                    combinedConditions{group} = cat(1, itcdataConditionByGroup{obj.conditionId,group});
                end;
                itcdata = cat(3, combinedConditions{:});
                
                
                % swap dimensions and linearize 3D matrix
                itcdataWithCompsFirst = permute(itcdata,[3 2 1]);
                obj.linearizedMeasure = itcdataWithCompsFirst(obj.icIndexForEachDipole,:)';
                obj.time = STUDY.cluster(1).itctimes;
                obj.frequency = STUDY.cluster(1).itcfreqs;
                
                obj = createSubsetInRelationToBrain(obj, obj.relationshipToBrainVolume);
            end;
        end;        
    end;
end