function [outputPolarity scalpMapCorrelation]= normalize_ic_polarity(scalpMap, polarityisFixed)
% outputPolarity = normalize_ic_polarity(scalpMap, polarityisFixed)
% % scalpMap is N x Q array for N ICs, each with Q elements in their scalpmap
% % optional polarityisFixed is 1 x N

if nargin < 2
    polarityisFixed = false(1,size(scalpMap,1));
end;

% initialize with nans
outputPolarity = nan(1, size(scalpMap,1));

% scalpMap = [];
% for i=1:length(STUDY.cluster(1).topoall)
%     scalpMap = cat(1, scalpMap, STUDY.cluster(1).topoall{i}(:)');
% end;

% remove NANs
sum1 = sum(scalpMap,1);
scalpMap(:, isnan(sum1)) = [];

% calculate correlations between scalp maps
scalpMapCorrelation = corrcoef(scalpMap');

% remove the diagonal
scalpMapCorrelation = scalpMapCorrelation - diag(diag(scalpMapCorrelation));

if ~any(polarityisFixed) % if there are no ICs with fixed polarities in the beginning
    
    % find the highest abs. correlated pair with non-fixed polarity
    surrogateScalpMapCorrelation = abs(scalpMapCorrelation);
    surrogateScalpMapCorrelation(polarityisFixed, polarityisFixed) = -Inf;
    
    [dummy id1D] = max(surrogateScalpMapCorrelation(:));
    [pairIc(1) pairIc(2)] = ind2sub(size(surrogateScalpMapCorrelation), id1D);
    
    % first we chnage the polarity of each IC of this pair based on the sign of their mean scalp map
    for i=1:2
        pairIc1MeanPolarity(i) = mean(scalpMap(pairIc(i),:));
        outputPolarity(pairIc(i)) = sign(pairIc1MeanPolarity(i));
    end;
    
    % then we see if after this polarity chance they are still anti-correlated.
    % if so, we change the polarity of the IC with minimum abs. mean scalp map. (since this one has the
    % mean with least confidence between the two)
    if scalpMapCorrelation(pairIc(1), pairIc(2)) * outputPolarity(pairIc(1)) * outputPolarity(pairIc(2)) < 0
        [dummy id] = min(abs(pairIc1MeanPolarity));
        outputPolarity(pairIc(id)) = -outputPolarity(pairIc(id));
    end;
    
    polarityisFixed(pairIc) = true; % fix the polarity of the first pair
end;

% now we go through ICs with non-fixed polarities and find the most similar (abs. correlated) IC
% with any of the fixed polarity ICs. Then we set the polarity if this new IC accordingly and fix
% it.
for i=1:sum(~polarityisFixed)
    
    absCorrelationWithFixedPolarityScalpMap = abs(scalpMapCorrelation(:, polarityisFixed));
    absCorrelationWithFixedPolarityScalpMap(polarityisFixed,:) = -Inf; % ignore fixed-polarity ICs
    
    % maximum over all fixed-polarity ICs
    maxAbsCorrelationWithFixedPolarityScalpMapOverFixedPolarity = max(absCorrelationWithFixedPolarityScalpMap,[],2);
    
    % find the non-polarity fixed ICs with max abs. correlation to the group of fixed-polarity ICs
    [dummy icId] = max(maxAbsCorrelationWithFixedPolarityScalpMapOverFixedPolarity);
    
    % find the fixed-polarity IC with which the newly found IC has the highest abs. correlation
    absCorrelation = abs(scalpMapCorrelation(icId,:));
    absCorrelation(~polarityisFixed) = -Inf; % ignore non-polarity fixed ICs
    [dummy fixedPolarityIcId] = max(absCorrelation);
    
    
    outputPolarity(icId) = sign(scalpMapCorrelation(icId, fixedPolarityIcId) * outputPolarity(fixedPolarityIcId));
    polarityisFixed(icId) = true;
end;
